
*******************  
Installing Astrocut
*******************

Using pip
=========

The easiest way to install Astrocut is using pip::

    pip install astrocut


From source
===========

To install the bleeding edge version from github without downloading,
run the following command::

  pip git+https://github.com/spacetelescope/astrocut.git

The latest development version of astrocut can be cloned from github
using this command::

    git clone https://github.com/spacetelescope/astrocut.git

To install astrocut (from the root of the source tree)::

    pip install .

   
